import React from 'react';
import { StyleSheet, Text, View, Switch, Button, TextInput, FlatList, TouchableOpacity, KeyboardAvoidingView} from 'react-native';
import Collapsible from 'react-native-collapsible';
import { material } from 'react-native-typography';
import { Metrics, Colors } from '../Themes';
import { TextField } from 'react-native-material-textfield';
import { Entypo } from '@expo/vector-icons';
import {LinearGradient} from 'expo';
import {Platform} from 'react-native';

export default class ShoppingLists extends React.Component {

  static navigationOptions = ({ navigation }) => {
    const params = navigation.state.params || {};
    return {
      // title: 'PIGGYBAG',
      // headerTitleStyle: {
      //   alignSelf:'center',
      //   textAlign: 'center',
      // },
         headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
        headerLeft: (
          <TouchableOpacity onPress={ () => navigation.goBack() }>
            <View style= {{flex:1, flexDirection: 'row', alignItems: 'center', justifyContent:'flex-start'}}>
              <Entypo name="chevron-small-left"
                  size={Metrics.icons.xl}
                  color={"white"}
                  style={{padding:0, margin:0}}
              />
              {Platform.OS === 'ios' && <Text style={{color:"white", fontSize:15, textAlign:'left'}}> Back </Text>}
            </View>
          </TouchableOpacity>
        ),
       headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
       headerTitle: 'Shopping',
       tabBarIcon: ({ tintColor }) =>(
        <Entypo name="shopping-cart"
              size={Metrics.tabBarIcon}
              color={tintColor}
              />
        ),
      tabBarLabel: 'My List',
    };
  };

  state = {
    solo: false,
    items: [
      {name:'Heinz Ketchup', count: 1, notes: "No notes", collapsed: true, unit: "Bottle", status: 'none'},
      {name:'Oreo Thin White', count: 1, notes: "No notes", collapsed: true, unit: "Pack", status: 'none'},
      {name:'Tide Pods (48 Packets)', count: 1, notes: "No notes", collapsed: true, unit: "Container", status: 'none'},
      {name:'Energizer AA Batteries (24)', count: 1, notes: "No notes", collapsed: true, unit: "Strip", status: 'none'},
      {name:'Letter Size Paper', count: 1, notes: "No notes", collapsed: true, unit: "Box", status: 'none'},
      {name:'Blue Pen', count: 5, notes: "No notes", collapsed: true, unit: "", status: 'none'},
    ],
  }

  componentWillMount() {
    console.log("Shopping Lists will mount")
  }

  componentDidMount() {
    console.log("Shopping Lists did mount")
  }

  componentWillReceiveProps = ()=>{
    console.log("Shopping Lists will receive props")
  }

  addItem = (name, count, unit, notes) => {
    items = this.state.items.slice();
    items.push({'name': name, 'count': count, 'notes': notes, collapsed: true});
    this.setState({items});

    console.log(name);
  }

  expandItem = (index) => {
    this.state.items[index].collapsed = !this.state.items[index].collapsed;

    this.setState({items: this.state.items});
  }

  buyItem = (index) => {
    if(this.state.items[index].status == 'none'){
      this.state.items[index].status = 'line-through';
    }else{
      this.state.items[index].status = 'none';
    }

    this.setState({items: this.state.items});
  }

  _renderItem = ({item, index}) => {
    return (
      <TouchableOpacity style={styles.group} onPress={() => this.buyItem(index)}>
        <View style={styles.contentHeader}>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {textDecorationLine: item.status, color: "#4c4c4d", fontSize: 16}]}>{item.name}, {item.count} {item.unit}</Text>
          </View>
          <View style={styles.iconContainer}>

            <View>
            <Entypo name="chevron-small-down"
                size={Metrics.icons.medium}
                color={"#4c4c4d"}
                onPress={() => this.expandItem(index)}
                />
            </View>
          </View>
        </View>
     <Collapsible collapsed={item.collapsed}>
        <View style={[styles.topicText]}>
          <Text style={[material.subheading, {textAlign: "center", color: "#4c4c4d", fontSize: 16}]}> {item.notes}</Text>
        </View>
      </Collapsible> 
      </TouchableOpacity>

    )
  }

  pressAddItem = () => {
    this.props.navigation.navigate('AddItemScreen', {addItem: this.addItem})
  }

  completeShopping = () => {
    this.props.navigation.navigate('AttachReceipt');
  }

  togglePressed = () => {
    this.setState({solo: !this.state.solo});
  }
  _keyExtractor = (item, index) => index.toString();

  render() {
    let emptyList = null;
    if (!this.state.items[0]) {
      emptyList = (<Text style={styles.emptyListMessage}>No items exist yet!</Text>);
    }
    return (
      <View style={styles.mainContainer}>
        {emptyList}
        <TouchableOpacity style = {styles.filterBar}>
          <Text style={{alignSelf: 'center', margin: 5, fontSize: 18, color: "#4c4c4d"}}> See my items only </Text>
          <Switch
          onValueChange = {this.togglePressed}
          value = {this.state.solo} />
        </TouchableOpacity>
        <Text style ={{margin: 10, color: '#dd4f60'}}>
          Tap the items that you decide to buy
        </Text>
        <View style = {styles.listContainer}>
          <FlatList
            data={this.state.items}
            renderItem={this._renderItem}
            style={styles.container}
            keyExtractor={this._keyExtractor}
            extraData={this.state}
          />
            <TouchableOpacity
            style={styles.button}
            onPress={this.completeShopping}
            > 
              <LinearGradient colors={['#dd4f60', '#985695']} 
                start={{ x: 0, y: 1 }}
                end={{ x: 1, y: 1 }}
                style={styles.gradientButton}>
                  <Text style ={{ color: 'white', fontWeight: 'bold'}}> Done Shopping </Text>
              </LinearGradient>
            </TouchableOpacity>
          </View>
        </View>
         
    );
  }
}

const styles = StyleSheet.create({
  label:{
    flex: 1,
    flexDirection: 'column',
    justifyContent: "center",
    alignItems: "flex-start",
    paddingLeft: 10
  },
  filterBar: {
    flex: 2,
    backgroundColor: "#dddddd",
    marginBottom: 10,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: 5,
  },
  listContainer:{
    flex: 15,
  },
  button: {
    alignItems: 'center',
    margin: 10,
  },
  gradientButton:{
    padding: 10,
    width: Metrics.screenWidth*0.8,
    alignItems: 'center',
    borderRadius: 20,
    margin: 10,
  },
  addButton: {
    margin: 10,
    padding: 20,
    flexDirection: 'row',
    elevation: Metrics.smallMargin,
    borderRadius: Metrics.baseMargin,
    backgroundColor: "#e2e3e4",
  },
  text: {
    fontSize: Metrics.baseFontSize,
    paddingBottom: Metrics.basePadding,
  },
  container: {
    flex: 1,
    backgroundColor: "#ffffff",
  },
  group: {
    flex: 1,
    // height: Metrics.screenHeight*0.05,
    margin: Metrics.smallMargin,
    marginLeft: 10,
    marginRight: 10,
    flexDirection: "column",
    alignItems: "center",
    justifyContent: "space-between",
    // padding: 2,
    padding: 5,
    elevation: Metrics.smallMargin,
    borderRadius: Metrics.baseMargin,
    backgroundColor: "#e2e3e4",
  },
  topicText:{
    flex: 1,
    marginLeft: Metrics.baseMargin,
    flexDirection: "column",
    alignItems: "flex-start",
    justifyContent: "center",
    padding: 0,
  },
  mainContainer: {
    flex:1,
    backgroundColor: "#ffffff",
  },
  footer:{
    padding: 5 
  },
  iconContainer: {
    paddingRight: 10,
  },
  contentHeader: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
  },
  emptyListMessage :{
    flex: 1,
    textAlign: 'center',
    fontSize: Metrics.baseFontSize*2,
    color : 'white',
    marginTop: Metrics.navBarHeight,
  }
});
