import React from 'react';
import { StyleSheet, Text, View, Button, TextInput, FlatList, KeyboardAvoidingView, TouchableOpacity, AlertIOS } from 'react-native';
import { material } from 'react-native-typography';
import { Metrics, Colors } from '../Themes';
import { Entypo } from '@expo/vector-icons';
import { TextField } from 'react-native-material-textfield';
import {LinearGradient} from 'expo';
import {Platform} from 'react-native';

export default class AddItem extends React.Component {

  static navigationOptions = ({ navigation }) => {
    const params = navigation.state.params || {};
    return {
      // headerTitle: params.name,
      // headerTitleStyle: {
      //   fontSize: Metrics.baseFontSize*2,
      // },
      headerLeft: (
          <TouchableOpacity onPress={ () => navigation.goBack() }>
            <View style= {{flex:1, flexDirection: 'row', alignItems: 'center', justifyContent:'flex-start'}}>
            <Entypo name="chevron-small-left"
                  size={Metrics.icons.xl}
                  color={"white"}
                  style={{padding:0, margin:0}}
              />
              {Platform.OS === 'ios' && <Text style={{color:"white", fontSize:15, textAlign:'left'}}> Back </Text>}
            </View>
          </TouchableOpacity>
        ),
       headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
      headerTitle: 'Add Item',
      headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
      tabBarIcon: ({ tintColor }) => (
          <Entypo name="home"
            size={Metrics.tabBarIcon}
            color={tintColor} />
      ),
      tabBarLabel: 'My List',
    };
  };

  state = {
    text: "",
    question: "",
    answer: "",
    rooms: [],
    name: "",
    count: "",
    unit: "",
    notes: "",
  }

  submitItem = () => {
    if(this.state.name == "" || this.state.count == "" || this.state.unit == ""){
      console.log("Fix input");
    }else{
      // console.log(this.props.navigation.);
      console.log(this.state.name);
      this.props.navigation.state.params.addItem(this.state.name, this.state.count, this.state.unit, this.state.notes);
      this.props.navigation.goBack();
    }
  }

  render() {
    let emptyList = null;
    if (!this.state.rooms[0]) {
      emptyList = (<Text style={styles.emptyListMessage}>Add item page here!</Text>);
    }

    return (
      <KeyboardAvoidingView style={styles.container} 
      behavior="padding" enabled
      >
        <View style = {styles.entrySection}>
          <View style={styles.entry}>
            <Text>Item Name</Text>
            <View style = {styles.entryBox}>
            <TextInput
              placeholder = "Organic Grain Bars with Raisins"
              onChangeText = {(text) => this.setState({name: text})}
              fontSize = {20}
              underlineColorAndroid="transparent"
            />
            </View>
          </View>

          <View style={styles.entry}>
            <Text>Quantity</Text>
            <View style = {styles.entryBox}>
            <TextInput
              placeholder = "1"
              onChangeText = {(text) => this.setState({count: text})}
              fontSize = {20}
              underlineColorAndroid="transparent"
            />
            </View>
          </View>

          <View style={styles.entry}>
            <Text>Unit</Text>
            <View style = {styles.entryBox}>
            <TextInput
              placeholder = "Box"
              onChangeText = {(text) => this.setState({unit: text})}
              fontSize = {20}
              underlineColorAndroid="transparent"
            />
            </View>
          </View>

          <View style={styles.entry}>
            <Text>Notes</Text>
            <View style = {styles.entryBox}>
            <TextInput
              placeholder = "Get the 122 pack one"
              onChangeText = {(text) => this.setState({notes: text})}
              fontSize = {20}
              underlineColorAndroid="transparent"
            />
            </View>
          </View>
        </View>
        <View style = {styles.addItem}>
           <TouchableOpacity
            onPress={this.submitItem}
            > 
              <LinearGradient colors={['#dd4f60', '#985695']} 
                start={{ x: 0, y: 1 }}
                end={{ x: 1, y: 1 }}
                style={styles.gradientButton}>
                  <Text style ={{ color: 'white', fontWeight: 'bold'}}> Add New Item </Text>
              </LinearGradient>
            </TouchableOpacity>
        </View>
      </KeyboardAvoidingView>
      
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    justifyContent: 'space-around'
  },
  gradientButton:{
    padding: 10,
    width: Metrics.screenWidth*0.8,
    alignItems: 'center',
    borderRadius: 20,
  },
  entrySection:{
    justifyContent: 'center',
    flex: 7,
    marginRight: 10,
    marginLeft: 10,
  },
  entryBox:{
    borderBottomColor: '#D3D3D3',
    borderBottomWidth: 2, 
  },
  addItem:{
    flex: 3,
    alignItems: 'center',
  },
  emptyListMessage :{
    flex: 1,
    textAlign: 'center',
    fontSize: Metrics.baseFontSize*2,
    color : Colors.darkGreen,
    marginTop: Metrics.navBarHeight,
  },
  entry: {
    margin: 10
  }
});
