import React from 'react';
import { StyleSheet, Text, SafeAreaView, View, AsyncStorage, Image, TouchableOpacity, FlatList, Button } from 'react-native';
import { material } from 'react-native-typography';
import { Metrics, Colors, Images } from '../Themes';
import { Entypo, FontAwesome, Ionicons, MaterialCommunityIcons } from '@expo/vector-icons';
import {LinearGradient} from 'expo';
import {Platform} from 'react-native';

export default class NotificationsScreen extends React.Component {

  static navigationOptions = ({ navigation }) => {
      return {
      headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
      headerLeft: (
        <TouchableOpacity onPress={ () => navigation.goBack() }>
          <View style= {{flex:1, flexDirection: 'row', alignItems: 'center', justifyContent:'flex-start'}}>
          <Entypo name="chevron-small-left"
                size={Metrics.icons.xl}
                color={"white"}
                style={{padding:0, margin:0}}
            />
            {Platform.OS === 'ios' && <Text style={{color:"white", fontSize:15, textAlign:'left'}}> Back </Text>}
          </View>
        </TouchableOpacity>
      ),
      headerBackground: (
      <LinearGradient colors={['#dd4f60', '#985695']} 
        start={{ x: 0, y: 1 }}
        end={{ x: 1, y: 1 }}
        style={{ flex: 1}}>
      </LinearGradient>
      ),
      headerTitle: 'Shopping',
      tabBarIcon: ({ tintColor }) =>(
      <Entypo name="shopping-cart"
            size={Metrics.tabBarIcon}
            color={tintColor}
            />
      ),
     };
  };

  state = {}

  finish = () =>{
    this.props.navigation.navigate('ShoppingList');
  }

  render() {
    return (
        <View style = {styles.container}>
          <Image
            style={styles.stretch}
            resizeMode='stretch'
            source={Images.charging_icon}
          />
          <View style = {styles.closingMessage}>
           <TouchableOpacity
            style={styles.button}
            onPress={this.finish}
            > 
              <LinearGradient colors={['#dd4f60', '#985695']} 
                start={{ x: 0, y: 1 }}
                end={{ x: 1, y: 1 }}
                style={styles.gradientButton}>
                  <Text style ={{ color: 'white', fontWeight: 'bold'}}> Finish </Text>
              </LinearGradient>
            </TouchableOpacity>
          
          </View>
        </View>
    );
  }
}

const styles = StyleSheet.create({
  container:{
    flex: 20,
    backgroundColor: 'white'
  },
  closingMessage: {
    flex: 2,
  },
  button: {
    alignItems: 'center',
  },
  stretch: {
    flex: 18,
    alignSelf: 'stretch',
    // alignSelf: 'center',
    // width: 0.8*Metrics.screenWidth,
    width: undefined,
    height: undefined
  },
  contentHeader: {
    flex: 1,
    flexDirection: 'column',
  },
  iconContainer: {
    // backgroundColor: "white",
    flex: 1,
    alignItems: "flex-end",
  },
  gradientButton:{
    padding: 10,
    width: Metrics.screenWidth*0.8,
    alignItems: 'center',
    borderRadius: 20,
  },
  notification: {
    // backgroundColor: "#e2e3e4",
    flex: 0.10,
    margin: 7,
    flexDirection: "column",
    elevation: Metrics.smallMargin*2,
    shadowOpacity: 0.50,
    shadowRadius: 3,
    shadowColor: 'black',
    shadowOffset: { height: 1, width: 2 },
    borderRadius: Metrics.baseMargin,
    padding: 2,
  },
   group: {
    alignItems: "flex-start",
    justifyContent: "space-between",
  },
  topicText: {
    flexDirection: "row",
    alignItems: "flex-start",
    margin: 5,
  }

});
