import React from 'react';
import { StyleSheet, Text, SafeAreaView, View, AsyncStorage, Image, TouchableOpacity, FlatList, Button } from 'react-native';
import { material } from 'react-native-typography';
import { Metrics, Colors, Images } from '../Themes';
import { Entypo, FontAwesome, Ionicons, MaterialCommunityIcons } from '@expo/vector-icons';
import {LinearGradient} from 'expo';

export default class ShoppingScreen extends React.Component {

  static navigationOptions = ({ navigation }) => {
      return {
         headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
        headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
        headerTitle: 'Shopping',
        // title: 'Notifications',
        tabBarIcon: ({ tintColor }) =>(
        <Entypo name="shopping-cart"
              size={Metrics.tabBarIcon}
              color={tintColor}
              />
        ),
     };
  };

  state = {
    notifications: [
      {message:'You are currently near', title: 'Safeway Palo Alto', subtext: '(2.5)mi', action: 'Go Shopping', color: "#e2e3e4"},
      {message:'Fabian has some important items to buy', title: 'Lay\'s Chip Vinegar Salt', subtext: '(and 6 more items)', action: 'Group List', color: "#e2e3e4"},
      {message:'You have Pending Payments for Fabian', title: '$36.12', subtext: '(September 30)', action: 'Pay Fabian Back', color: "#efd5e1"},
      {message:'You have Pending Payments for S', title: '$36.12', subtext: '(September 30)', action: 'Pay Fabian Back', color: "#efd5e1"},
    ],
  }

  onPressClear = () => {
    this.setState({notifications: []});
  }

  checkIn = () => {
    this.props.navigation.navigate('ActiveShopping');
  }

  render() {
    return (
        <View style = {styles.container}>
          <View style={styles.container2}>
              <View style = {styles.image}>
                <Image
                  resizeMode='center'
                  source={Images.shopping_icon}
                  style = {styles.stretch}
                />
              </View>
              <TouchableOpacity style = {styles.question}>
                <Text style={{color: '#dd4f60'}}>Are you somewhere else?</Text>
              </TouchableOpacity>
              <View style = {styles.question}>
                <Text style={{textAlign: 'center'}}>By checking in, you can let your group members know that you're shopping!</Text>
              </View>
          </View>

          <View style = {styles.test}>
            <TouchableOpacity
            style={styles.button}
            onPress={this.checkIn}
            > 
              <LinearGradient colors={['#dd4f60', '#985695']} 
                start={{ x: 0, y: 1 }}
                end={{ x: 1, y: 1 }}
                style={styles.gradientButton}>
                  <Text style ={{ color: 'white', fontWeight: 'bold'}}> Check In </Text>
              </LinearGradient>
            </TouchableOpacity>
            <TouchableOpacity style = {[styles.question, {margin: 10}]}>
                <Text style={{color: '#dd4f60'}}>Skip</Text>
            </TouchableOpacity>
           
          </View>
        </View>


    );
  }
}

const styles = StyleSheet.create({
  container:{
    flex: 1,
    flexDirection: 'column',
    backgroundColor: 'white',
  },
  button: {
    alignItems: 'center',
  },
  gradientButton:{
    padding: 10,
    width: Metrics.screenWidth*0.8,
    alignItems: 'center',
    borderRadius: 20,
  },
  container2: {
    flex: 8,
    flexDirection: 'column',
    alignItems: 'center',
  },
  image: {
    flex: 3,
  },
  question: {
    flex: 1,
    margin: 10
  },
  test: {
    flex: 3,
    alignItems: 'center',
    // backgroundColor: 'black'
  },
  stretch: {
    flex: 1,
    flexDirection: 'column',
    justifyContent: 'flex-end',
    alignItems: 'flex-end'
    // flexDirection: 'column',
    // alignItems: 'center',
    // justifyContent: 'center',
    // backgroundColor: 'green'
  },
  contentHeader: {
    flex: 1,
    flexDirection: 'column',
  },
  iconContainer: {
    // backgroundColor: "white",
    flex: 1,
    alignItems: "flex-end",
  },
  notification: {
    // backgroundColor: "#e2e3e4",
    flex: 0.10,
    margin: Metrics.smallMargin,
    flexDirection: "column",
    elevation: Metrics.smallMargin*2,
    shadowOpacity: 0.50,
    shadowRadius: 3,
    shadowColor: 'black',
    shadowOffset: { height: 1, width: 2 },
    borderRadius: Metrics.baseMargin,
    padding: 2,
  },
   group: {
    alignItems: "flex-start",
    justifyContent: "space-between",
  },
  topicText: {
    flexDirection: "row",
    alignItems: "flex-start",
    margin: 5,
  }

});
