import React from 'react';
import { StyleSheet, Text, View, Switch, Button, TextInput, FlatList, TouchableOpacity, KeyboardAvoidingView} from 'react-native';
import Collapsible from 'react-native-collapsible';
import { material } from 'react-native-typography';
import { Metrics, Colors } from '../Themes';
import { Entypo } from '@expo/vector-icons';
import { TextField } from 'react-native-material-textfield';
import {LinearGradient} from 'expo';

export default class ShoppingLists extends React.Component {

  static navigationOptions = ({ navigation }) => {
    const params = navigation.state.params || {};
    return {
      // title: 'PIGGYBAG',
      // headerTitleStyle: {
      //   alignSelf:'center',
      //   textAlign: 'center',
      // },
      title: 'PiggyBag',
      headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },

       headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
       tabBarIcon: ({ tintColor }) => (
        <Entypo name="home"
          size={Metrics.tabBarIcon}
          color={tintColor}
          />
      ),
       tabBarLabel: ({ tintColor }) => (
          <Text style={{color:tintColor, fontWeight: 'bold', 'fontSize': 20}}>Group List</Text>
      )
    };
  };

  state = {
    solo: true,
    items: [
      {name:'Heinz Ketchup', count: 1, notes: "No notes", collapsed: true, unit: "Bottle", status: 'none'},
      {name:'Oreo Thin White', count: 1, notes: "No notes", collapsed: true, unit: "Pack", status: 'none'},
      {name:'Tide Pods (48 Packets)', count: 1, notes: "No notes", collapsed: true, unit: "Container", status: 'none'},
      {name:'Energizer AA Batteries (24)', count: 1, notes: "No notes", collapsed: true, unit: "Strip", status: 'none'},
      {name:'Letter Size Paper', count: 1, notes: "No notes", collapsed: true, unit: "Box", status: 'none'},
      {name:'Blue Pen', count: 5, notes: "No notes", collapsed: true, unit: "", status: 'none'},
    ],
  }

  componentWillMount() {
    console.log("Shopping Lists will mount")
  }

  componentDidMount() {
    console.log("Shopping Lists did mount")
  }

  componentWillReceiveProps = ()=>{
    console.log("Shopping Lists will receive props")
  }

  addItem = (name, count, unit, notes) => {
    items = this.state.items.slice();
    items.push({'name': name, 'count': count, 'unit': unit, 'notes': notes, collapsed: true});
    this.setState({items});

    console.log(name);
  }

  expandItem = (index) => {
    console.log(this.state.items[index].collapsed);
    this.state.items[index].collapsed = !this.state.items[index].collapsed;

    this.setState({items: this.state.items});
  }

  _renderItem = ({item, index}) => {
    return (
      <TouchableOpacity style={styles.group} onPress={() => this.expandItem(index)}>
        <View style={styles.contentHeader}>
          <View style={styles.topicText}>
            <Text style={[material.subheading, {padding:0, color: "#4c4c4d", fontSize: 16}]}>{item.name}, {item.count} {item.unit}</Text>
          </View>
          <View style={styles.iconContainer}>
            <Entypo name="chevron-small-down"
                size={Metrics.icons.medium}
                color={"#4c4c4d"}
              />
          </View>
        </View>
     <Collapsible collapsed={item.collapsed}>
        <View style={styles.topicText}>
          <Text style={[material.subheading, {padding: 0, color: "#4c4c4d", fontSize: 16}]}> {item.notes}</Text>
        </View>
      </Collapsible> 
      </TouchableOpacity>

    )
  }

  pressAddItem = () => {
    this.props.navigation.navigate('AddItemScreen', {addItem: this.addItem})
  }

  _keyExtractor = (item, index) => index.toString();

  togglePressed = () => {
    this.setState({solo: !this.state.solo});
  }
  
  render() {
    let emptyList = null;
    if (!this.state.items[0]) {
      emptyList = (<Text style={styles.emptyListMessage}>No items exist yet!</Text>);
    }
    return (
      <View style={styles.mainContainer}>
        <TouchableOpacity style = {styles.filterBar}>
        <Text style={{alignSelf: 'center', margin: 5, fontSize: 18, color: "#4c4c4d"}}> See my items also </Text>
        <Switch
          onValueChange = {this.togglePressed}
          value = {this.state.solo} />
      </TouchableOpacity>
        {emptyList}
        <View style = {styles.listContainer}>
          <FlatList
            data={this.state.items}
            renderItem={this._renderItem}
            style={styles.container}
            keyExtractor={this._keyExtractor}
            extraData={this.state}
          />
        </View>
        </View>
    );
  }
}

const styles = StyleSheet.create({
  label:{
    flex: 1,
    flexDirection: 'column',
    justifyContent: "center",
    alignItems: "flex-start",
    paddingLeft: 10
  },
  listContainer:{
    flex: 15,
  },
  filterBar: {
    flex: 2,
    backgroundColor: "#dddddd",
    marginBottom: 10,
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: 5,
  },
  addButton: {
    margin: 10,
    flexDirection: 'row',
    alignItems: 'flex-start',
    justifyContent: 'center',
    height: Metrics.screenHeight*0.05,
    elevation: Metrics.smallMargin,
    borderRadius: Metrics.baseMargin*0.1,
    backgroundColor: "#e2e3e4",
  },
  text: {
    fontSize: Metrics.baseFontSize,
    paddingBottom: Metrics.basePadding,
  },
  container: {
    flex: 1,
    backgroundColor: "#ffffff",
  },
  group: {
    flex: 1,
    // height: Metrics.screenHeight*0.05,
    margin: Metrics.smallMargin,
    marginLeft: 10,
    marginRight: 10,
    flexDirection: "column",
    alignItems: "center",
    justifyContent: "space-between",
    // padding: 2,
    padding: 5,
    elevation: Metrics.smallMargin,
    borderRadius: Metrics.baseMargin,
    backgroundColor: "#e2e3e4",
  },
  topicText:{
    flex: 1,
    marginLeft: Metrics.baseMargin,
    flexDirection: "column",
    alignItems: "flex-start",
    justifyContent: "center",
    padding: 0,
  },
  mainContainer: {
    flex:1,
    backgroundColor: "#ffffff",
  },
  footer:{
    padding: 5 
  },
  iconContainer: {
    paddingRight: 10,
  },
  iconContainerPlus: {
    paddingLeft: 10,
  },
  contentHeader: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
  },
  emptyListMessage :{
    flex: 1,
    textAlign: 'center',
    fontSize: Metrics.baseFontSize*2,
    color : 'white',
    marginTop: Metrics.navBarHeight,
  }
});
