import React from 'react';
import { StyleSheet, Text, SafeAreaView, View, AsyncStorage, Image, TouchableOpacity, FlatList, Button } from 'react-native';
import { material } from 'react-native-typography';
import { Metrics, Colors, Images } from '../Themes';
import { Entypo, FontAwesome, Ionicons, MaterialCommunityIcons } from '@expo/vector-icons';
import {LinearGradient} from 'expo';

export default class NotificationsScreen extends React.Component {

  static navigationOptions = ({ navigation }) => {
      return {
        headerMode: 'none', 
        navigationOptions: {
          headerVisible: false,
        },
      headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
        headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
        headerTitle: 'History',
        // title: 'Notifications',
        tabBarIcon: ({ tintColor }) =>(
        <MaterialCommunityIcons name="clock"
              size={Metrics.tabBarIcon}
              color={tintColor}
              />
        ),
     };
  };

  state = {
    history: [
      {month:'OCT', date:'11', shopper: 'Simon', shoppee: 'James', subtext: 'Payment Complete ($32.68)', action: 'See Details', color: "#e2e3e4"},
      {month:'OCT', date:'03', shopper: 'James', shoppee: 'Simon', subtext: 'Payment Complete ($11.20)', action: 'See Details', color: "#e2e3e4"},
      {month:'SEPT', date:'03', shopper: 'Fabian', shoppee: 'Simon', subtext: 'Payment Pending ($36.12)', action: 'See Details', color: "#efd5e1"},
      {month:'SEPT', date:'03', shopper: 'Simon', shoppee: 'Fabian', subtext: 'Payment Complete ($11.20)', action: 'See Details', color: "#e2e3e4"},
      {month:'AUG', date:'03', shopper: 'James', shoppee: 'Simon', subtext: 'Payment Complete ($11.20)', action: 'See Details', color: "#e2e3e4"},
      {month:'JULY', date:'03', shopper: 'James', shoppee: 'Simon', subtext: 'Payment Complete ($11.20)', action: 'See Details', color: "#e2e3e4"},
      {month:'JUNE', date:'03', shopper: 'James', shoppee: 'Simon', subtext: 'Payment Complete ($11.20)', action: 'See Details', color: "#e2e3e4"},
    ],
  }

  _keyExtractor = (item, index) => index.toString();

  _renderItem = ({item, index}) => {
    return (
      <TouchableOpacity style={[styles.historyItem, {backgroundColor: item.color}]}>
        <View style={styles.group}>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {textAlign: "center", color: "black", fontWeight: 'bold', fontSize: 10}]}>{item.month} {item.date}</Text>
          </View>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {marginBottom:0, padding: 0, textAlign: "center", color: "black", fontWeight: '300', fontSize: 15}]}><Text style={{fontWeight: 'bold', color: '#985695'}}>{item.shopper}</Text> shopped for <Text style={{fontWeight: 'bold', 'color': '#985695'}}>{item.shoppee}</Text></Text>
            <Text style={[material.subheading, {marginTop:0, padding: 0, textAlign: "center", color: "black", fontWeight: '300', fontSize: 10}]}>{item.subtext}</Text>
          </View>
       
        </View>
        <View style={styles.iconContainer}>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {marginRight:5, textAlign: "center", color: "#d13e56", fontSize: 12}]}> {item.action}</Text>
          </View>
        </View>
      </TouchableOpacity>

    )
  }

  render() {
    return (
        <View style = {styles.container}>
          <TouchableOpacity style = {styles.filterBar}>
            <Ionicons
              name="ios-options"
              color={"#dd4f60"}
              size={Metrics.tabBarIcon*0.9}
            />
            <Text style={{alignSelf: 'center', margin: 5, fontSize: 18, color: "#dd4f60"}}> Filter </Text>
          </TouchableOpacity>
          <View style = {styles.listContainer}>
          <FlatList
            data={this.state.history}
            renderItem={this._renderItem}
            // style={styles.container}
            keyExtractor={this._keyExtractor}
            extraData={this.state}
          />
          </View>
        </View>
    );
  }
}

const styles = StyleSheet.create({
  container:{
    flex: 20,
    // backgroundColor: 'white'
  },
  filterBar: {
    flex: 2,
    backgroundColor: "#dddddd",
    marginBottom: 10,
    flexDirection: 'row',
    alignItems: 'center',
    padding: 5,
  },
  listContainer:{
    flex: 18,
  },
  iconContainer: {
    // backgroundColor: "white",
    flex: 1,
    alignItems: "flex-end",
  },
  historyItem: {
    backgroundColor: "#e2e3e4",
    flex: 0.1,
    margin: 7,
    flexDirection: "column",
    elevation: Metrics.smallMargin*2,
    shadowOpacity: 0.50,
    shadowRadius: 3,
    shadowColor: 'black',
    // height: Metrics.screenHeight*0.10,
    shadowOffset: { height: 1, width: 2 },
    borderRadius: Metrics.baseMargin,
    padding: 1,
  },
   group: {
    alignItems: "flex-start",
    // justifyContent: "space-between",
  },
  topicText: {
    flexDirection: "column",
    alignItems: "flex-start",
    marginTop: 1,
    marginLeft: 5,
  }

});
