import React from 'react';
import { StyleSheet, Text, SafeAreaView, View, AsyncStorage, Image, TouchableOpacity, FlatList, Button } from 'react-native';
import { material } from 'react-native-typography';
import { Metrics, Colors, Images } from '../Themes';
import { Entypo, FontAwesome, Ionicons } from '@expo/vector-icons';
import {LinearGradient} from 'expo';

export default class NotificationsScreen extends React.Component {

  static navigationOptions = ({ navigation }) => {
      return {
      headerTitleStyle: {
        color: Colors.snow,
        fontSize: 25,
        textAlign: 'center',
        alignSelf: 'center',
      },
        headerBackground: (
        <LinearGradient colors={['#dd4f60', '#985695']} 
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={{ flex: 1}}>
        </LinearGradient>
      ),
        headerTitle: 'Notifications',
        tabBarIcon: ({ tintColor }) =>(
        <Ionicons name="ios-notifications"
              size={Metrics.tabBarIcon*1.1}
              color={tintColor}
              />
        ),
     };
  };

  state = {
    notifications: [
      {message:'You are currently near', title: 'Safeway Palo Alto', subtext: '(2.5)mi', action: 'Go Shopping', color: "#e2e3e4"},
      {message:'Fabian has some important items to buy', title: 'Lay\'s Chip Vinegar Salt', subtext: '(and 6 more items)', action: 'Group List', color: "#e2e3e4"},
      {message:'You have Pending Payments for Fabian', title: '$36.12', subtext: '(September 30)', action: 'Pay Fabian Back', color: "#efd5e1"},
      {message:'You have Pending Payments for James', title: '$45.12', subtext: '(October 30)', action: 'Pay James Back', color: "#efd5e1"},
    ],
  }

  expandItem = (index) => {
    action = this.state.notifications[index].action;
    if(action == "Go Shopping"){
      this.props.navigation.navigate('Shopping');
    }else if(action == "Group List"){
      this.props.navigation.navigate('GroupList');
    }
  }

  _keyExtractor = (item, index) => index.toString();

  _renderItem = ({item, index}) => {
    return (
      <TouchableOpacity style={[styles.notification, {backgroundColor: item.color}]} onPress={() => this.expandItem(index)}>
        <View style={styles.group}>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {textAlign: "center", color: "black", fontWeight: 'bold', fontSize: 12}]}> {item.message} </Text>
          </View>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {textAlign: "center", color: "black", fontWeight: '300', fontSize: 18}]}> {item.title} </Text>
            <Text style={[material.subheading, {textAlign: "center", color: "black", fontWeight: '300', fontSize: 13}]}> {item.subtext} </Text>
          </View>
       
        </View>
        <View style={styles.iconContainer}>
          <View style={[styles.topicText]}>
            <Text style={[material.subheading, {textAlign: "center", color: "#d13e56", fontSize: 15}]}> {item.action}</Text>
          </View>
        </View>
      </TouchableOpacity>

    )
  }

  onPressClear = () => {
    this.setState({notifications: []});
  }

  render() {
    return (
        <View style = {styles.container}>
          <Image
            style={styles.stretch}
            resizeMode='stretch'
            source={Images.notification_screen}
          />
          <TouchableOpacity onPress={this.onPressClear}>
            <Text style={[material.subheading, {margin: 10, marginTop:0, textAlign: "right", color: "#d13e56", fontSize: 15}]}>Clear All</Text>
          </TouchableOpacity>
          
          <View style = {styles.listContainer}>
            <FlatList
              data={this.state.notifications}
              renderItem={this._renderItem}
              keyExtractor={this._keyExtractor}
              extraData={this.state}
            />
          </View>
        </View>


    );
  }
}

const styles = StyleSheet.create({
  container:{
    flex: 1,
    backgroundColor: 'white'
  },
  listContainer: {
    flex: 0.8,
  },
  stretch: {
    flex: 0.6,
    alignSelf: 'stretch',
    // alignSelf: 'center',
    // width: 0.8*Metrics.screenWidth,
    width: undefined,
    height: undefined
  },
  contentHeader: {
    flex: 1,
    flexDirection: 'column',
  },
  iconContainer: {
    // backgroundColor: "white",
    flex: 1,
    alignItems: "flex-end",
  },
  notification: {
    // backgroundColor: "#e2e3e4",
    flex: 0.10,
    margin: 7,
    flexDirection: "column",
    elevation: Metrics.smallMargin*2,
    shadowOpacity: 0.50,
    shadowRadius: 3,
    shadowColor: 'black',
    shadowOffset: { height: 1, width: 2 },
    borderRadius: Metrics.baseMargin,
    padding: 2,
  },
   group: {
    alignItems: "flex-start",
    justifyContent: "space-between",
  },
  topicText: {
    flexDirection: "row",
    alignItems: "flex-start",
    margin: 5,
  }

});
